@@ -1,5 +1,4 @@
-from outcome.pypicloud_access_github import cache
 from outcome.pypicloud_access_github.access import Access
 from outcome.pypicloud_access_github.poetry import Poetry
 
-__all__ = ['Poetry', 'Access', 'cache']
+__all__ = ['Poetry', 'Access']
